@@ -6,7 +6,6 @@ from compass.core import errors
 from compass.core import logger
 from compass.core.hierarchy import Hierarchy
 from compass.core.logon import login
-from compass.core.logon import Logon
 from compass.core.people import People
 from compass.core.reports import Reports
 
@@ -16,7 +15,6 @@ __all__ = (
     "logger",
     # public classes
     "Hierarchy",
-    "Logon",
     "People",
     "Reports",
     # public functions
